%ifarch armv7hl %ix86
# -g causes linker to run out of memory
%global debug_package %{nil}
%endif

Summary:        The free/open-source library for quantitative finance
Name:           quantlib-swig
Version:        1.37
Release:        %mkrel 3
License:        BSD License
Group:          System/Libraries
URL:            https://www.quantlib.org/
Source0:        https://github.com/lballabio/QuantLib-SWIG/releases/download/v%{version}/QuantLib-SWIG-%{version}.tar.gz

BuildRequires:  boost-devel >= 1.34.1
BuildRequires:  pkgconfig(python3)
BuildRequires:  swig
BuildRequires:  quantlib-devel >= %{version}
BuildRequires:  R-base

# needed for R-quantlib manual
BuildRequires:  texlive

%description
Alternative language bindings for quantlib.

%package -n r-quantlib
Summary:        R bindings for Quantlib
Group:          Sciences/Mathematics
Requires:       R-base

%description -n r-quantlib
R bindings for Quantlib.

%package -n python3-quantlib
Summary:        Python 3 bindings for Quantlib
Group:          Development/Python

%description -n python3-quantlib
Python 3 bindings for Quantlib.

%prep
%autosetup -p1 -n QuantLib-SWIG-%{version}

find -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python3}|'

%build
autoreconf --force --install
export CXXFLAGS="-O2 %{Werror_cflags} --param ggc-min-expand=20 -fPIE"
export CFLAGS="-O2 %{Werror_cflags} --param ggc-min-expand=20 -fPIE"
%configure --disable-static --prefix=%{_prefix}
# make clean to remove old swig files
make clean
pushd Python
# need to build by hand to avoid pipe which exhausts memory on i586
swig -python -c++ \
     -outdir src/QuantLib -o quantlib_wrap.cpp ../SWIG/quantlib.i
%{__cxx} -O2 -Wformat -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector \
    --param=ssp-buffer-size=4 -fasynchronous-unwind-tables  -fPIC -fwrapv \
    --param ggc-min-expand=1 --param ggc-min-heapsize=51200 -c quantlib_wrap.cpp \
    -I`python3 -c 'import distutils.sysconfig ; print(distutils.sysconfig.get_config_vars("CONFINCLUDEPY")[0])'` \
    -o quantlib_wrap.o
%{__cxx} -shared quantlib_wrap.o -L/usr/lib -L/usr/lib64 -lpython3 -lQuantLib \
-o _QuantLib`python3 -c 'import distutils.sysconfig ; print(distutils.sysconfig.get_config_vars("SO")[0])'`
%{__python3} setup.py egg_info
popd
pushd R
touch .build-stamp
swig -r -c++ -o src/QuantLib.cpp ../SWIG/quantlib.i
popd

%install
pushd Python
mkdir -p %{buildroot}%{python3_sitearch}/QuantLib
cp src/QuantLib/*.py %{buildroot}%{python3_sitearch}/QuantLib
cp src/QuantLib.egg-info/PKG-INFO \
   %{buildroot}%{python3_sitearch}/QuantLib_Python-%{version}-py`python3 -c 'import distutils.sysconfig ; print(distutils.sysconfig.get_config_vars("VERSION")[0])'`.egg-info
popd
pushd R
mkdir -p %{buildroot}%{_libdir}/R/library
echo 'PKG_CPPFLAGS=--param ggc-min-expand=20' >  src/Makevars
echo 'PKG_LIBS=-lQuantLib' >>  src/Makevars
# need to build by hand to avoid pipe which exhausts memory
%ifarch armv7hl %ix86
pushd src
%{__cxx} -I%{_libdir}/R/include -DNDEBUG --param ggc-min-expand=20  -I/usr/local/include   -fPIC -O2 -Wformat -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 -fstack-protector --param=ssp-buffer-size=4 -fasynchronous-unwind-tables  -c QuantLib.cpp -o QuantLib.o
popd
%endif
R CMD INSTALL --library=%{buildroot}%{_libdir}/R/library .
popd
rm -rf %{buildroot}%{_docdir}

%files -n python3-quantlib
%{python3_sitearch}/QuantLib/
%{python3_sitearch}/*.egg-info

%files -n r-quantlib
%{_libdir}/R/library/QuantLib

%if 0%{?with_ruby}
%files -n ruby-quantlib
%{ruby_vendorarchdir}/QuantLibc.so
%{ruby_vendorlibdir}/QuantLib.rb
%endif


%changelog
* Tue Mar 04 2025 wally <wally> 1.37-3.mga10
+ Revision: 2160434
- rebuild for python3.13
+ daviddavid <daviddavid>
- rebuild for arm

* Sat Jan 25 2025 daviddavid <daviddavid> 1.37-1.mga10
+ Revision: 2142110
- new version: 1.37

* Wed Dec 04 2024 daviddavid <daviddavid> 1.36-1.mga10
+ Revision: 2121549
- new version: 1.36

* Sun Aug 18 2024 papoteur <papoteur> 1.35-1.mga10
+ Revision: 2086944
- new version 1.35

* Thu Mar 07 2024 papoteur <papoteur> 1.33-1.mga10
+ Revision: 2048345
- new version 1.33
+ daviddavid <daviddavid>
- rebuild for py3.12

* Mon Dec 19 2022 joequant <joequant> 1.28-1.mga9
+ Revision: 1925286
- fix compile flags
- replace quantlib-config
+ papoteur <papoteur>
- new 1.28

* Sat Apr 02 2022 umeabot <umeabot> 1.20-6.mga9
+ Revision: 1840612
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 1.20-5.mga9
+ Revision: 1778537
- Rebuild for python-3.10

* Wed Mar 24 2021 daviddavid <daviddavid> 1.20-4.mga9
+ Revision: 1708652
- rebuild for python 3.9

* Wed Nov 18 2020 joequant <joequant> 1.20-3.mga8
+ Revision: 1647151
- change build to avoid oom compile on arm

* Wed Nov 18 2020 joequant <joequant> 1.20-2.mga8
+ Revision: 1647028
- rebuild with new R

* Mon Nov 16 2020 joequant <joequant> 1.20-1.mga8
+ Revision: 1646657
- fix typo in cashflow.i
- update to 1.20

* Sun Jul 26 2020 joequant <joequant> 1.19-2.mga8
+ Revision: 1609026
- add patch
- bump release

* Sat Jul 25 2020 joequant <joequant> 1.19-1.mga8
+ Revision: 1608993
- update to 1.19

* Mon Jul 20 2020 joequant <joequant> 1.18.1-2.mga8
+ Revision: 1607309
- remove ruby / fix python typo

* Mon Jul 20 2020 joequant <joequant> 1.18.1-1.mga8
+ Revision: 1607304
- set Makevars
- set CXXFLAGS for R build
- typo
- fix typo
- add params
- update build method
- set CXXFLAGS
- remove pipe from python to reduce memory
- remove pipe for virtual memory limits
- update to 1.18.1
+ danf <danf>
- Switch URLs from http: to https:

* Tue Mar 03 2020 pterjan <pterjan> 1.16.1-9.mga8
+ Revision: 1553500
- Try harder to use the right flags

* Tue Mar 03 2020 pterjan <pterjan> 1.16.1-8.mga8
+ Revision: 1553394
- Also reduce memory usage when ruby binding gets built in install section

* Mon Mar 02 2020 pterjan <pterjan> 1.16.1-7.mga8
+ Revision: 1553147
- Rebuild for ruby 2.7

* Sun Feb 16 2020 umeabot <umeabot> 1.16.1-6.mga8
+ Revision: 1535855
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
+ joequant <joequant>
- fix build to use fewer resources - reenable arm builds

* Sun Oct 13 2019 tv <tv> 1.16.1-3.mga8
+ Revision: 1452757
- exclude arm/aarch64 for now
- perl module is no more
- drop python2 subpackage
- try to prevant "Cannot allocate memory" on ia32 too
- new release
+ joequant <joequant>
- fix permission change
- change permission to allow strip
+ daviddavid <daviddavid>
- rename python-quantlib to python2-quantlib
+ tmb <tmb>
- rebuild for perl 5.30

* Wed Apr 24 2019 pterjan <pterjan> 1.13-10.mga7
+ Revision: 1395216
- Fix stripping when debug is disabled

* Tue Apr 23 2019 pterjan <pterjan> 1.13-9.mga7
+ Revision: 1395031
- Try harder to reduce memory usage on armv7hl

* Sun Apr 21 2019 pterjan <pterjan> 1.13-8.mga7
+ Revision: 1394442
- Totally disable debug on armv7hl

* Tue Apr 09 2019 pterjan <pterjan> 1.13-7.mga7
+ Revision: 1387447
- Fix the way of passing -g1

* Tue Apr 09 2019 pterjan <pterjan> 1.13-6.mga7
+ Revision: 1387291
- Try another way to reduce memory usage (-g1)

* Wed Apr 03 2019 pterjan <pterjan> 1.13-5.mga7
+ Revision: 1385581
- Try to reduce memory usage on armv7 (g++ currently fails with "virtual memory exhausted: Cannot allocate memory")

* Tue Jan 08 2019 tv <tv> 1.13-4.mga7
+ Revision: 1351852
- rebuild with python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 1.13-3.mga7
+ Revision: 1300747
- Mageia 7 Mass Rebuild

* Thu Aug 09 2018 tv <tv> 1.13-2.mga7
+ Revision: 1250745
- rebuild for perl-5.28

* Fri Jul 27 2018 wally <wally> 1.13-1.mga7
+ Revision: 1245567
- new version 1.13
- drop intraday patch as it was also dropped from quantlib in 1.10.1-1.mga7 (r1178626)
+ pterjan <pterjan>
- Rebuild for Ruby 2.5

* Tue Sep 19 2017 tv <tv> 1.6-8.mga7
+ Revision: 1155562
- lazy fix for ruby dir
+ pterjan <pterjan>
- Rebuild for new Ruby

* Sun Aug 06 2017 joequant <joequant> 1.6-7.mga7
+ Revision: 1137944
- rebuild to python 3.6
+ pterjan <pterjan>
- Rebuild for python 3.6

* Sat Jul 22 2017 neoclust <neoclust> 1.6-6.mga7
+ Revision: 1126588
- Rebuild against new Perl 5.26
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Nov 11 2015 daviddavid <daviddavid> 1.6-6.mga6
+ Revision: 902029
- rebuild for new ruby 2.2.3

* Thu Oct 08 2015 joequant <joequant> 1.6-5.mga6
+ Revision: 887602
- upgrade to python 3.5

* Thu Aug 27 2015 cjw <cjw> 1.6-4.mga6
+ Revision: 870160
- rebuild with gcc 5

* Tue Jun 30 2015 joequant <joequant> 1.6-3.mga6
+ Revision: 848348
- upgrade to 1.6
- update to 1.6

* Sat Jun 27 2015 tv <tv> 1.5-3.mga6
+ Revision: 846157
- rebuild with soname-ified perl

* Wed Jun 24 2015 sander85 <sander85> 1.5-2.mga6
+ Revision: 841766
- Rebuild for perl 5.22
+ joequant <joequant>
- add git
- sync with latest quantlib

* Sat Mar 07 2015 joequant <joequant> 1.5-2.mga5
+ Revision: 818061
- bump release number
- bump version number
- add cryptofuture
- add default payoff
- add cryptocurrency
- bump to 1.5
- update to quantlib 1.5

* Thu Jan 15 2015 joequant <joequant> 1.4-2.mga5
+ Revision: 810772
- new intraday patch
- swig for new patch

* Wed Dec 24 2014 joequant <joequant> 1.4-1.mga5
+ Revision: 805189
- add texlive
- bump release. add depends
- add ruby and perl backends
- add intraday patches
- remove version for quantlib dep
- move description tag
- imported package quantlib-swig

